@@ -7,7 +7,7 @@ from enum import Enum
 from pickle import dumps, loads
 from tempfile import NamedTemporaryFile
 from types import TracebackType
-from typing import IO, Generic, Optional, Type, TypeVar, Union, cast
+from typing import IO, Generic, Optional, Tuple, Type, TypeVar, Union, cast, overload
 from uuid import uuid4
 
 from .logger import logger
@@ -16,9 +16,9 @@ if sys.version_info >= (3, 9):
     from contextlib import AbstractContextManager
 
     ContextManager = AbstractContextManager
-    from collections.abc import Callable
+    from collections.abc import Callable, Collection, Iterable, Iterator
 else:
-    from typing import Callable, ContextManager
+    from typing import Callable, Collection, ContextManager, Iterable, Iterator
 
 T = TypeVar("T")
 KT = TypeVar("KT")
@@ -27,12 +27,6 @@ _T = TypeVar("_T")
 _S = TypeVar("_S")
 
 
-class RebuildStrategy(Enum):
-    CHECK_WITH_FIRST_ELEMENT = 1
-    ALWAYS = 2
-    SKIP = 3
-
-
 def sanitize_table_name(table_name: str, prefix: str) -> str:
     ret = "".join(c for c in table_name if c.isalnum() or c == "_")
     if len(ret) == 0:
@@ -96,6 +90,16 @@ class TemporaryTableContext(ContextManager[str]):
 
 
 class _SqliteCollectionBaseDatabaseDriver(metaclass=ABCMeta):
+    if sys.version_info >= (3, 9):
+
+        @classmethod
+        @property
+        def schema_version(cls) -> str:
+            return ""
+
+    else:
+        schema_version = ""
+
     @classmethod
     def initialize_metadata_table(cls, cur: sqlite3.Cursor) -> None:
         if not cls.is_metadata_table_initialized(cur):
@@ -125,17 +129,13 @@ class _SqliteCollectionBaseDatabaseDriver(metaclass=ABCMeta):
         )
 
     @classmethod
-    def initialize_table(
-        cls, table_name: str, container_type_name: str, schema_version: str, cur: sqlite3.Cursor
-    ) -> None:
-        if not cls.is_table_initialized(table_name, container_type_name, schema_version, cur):
-            cls.do_create_table(table_name, container_type_name, schema_version, cur)
-            cls.do_tidy_table_metadata(table_name, container_type_name, schema_version, cur)
+    def initialize_table(cls, table_name: str, container_type: str, cur: sqlite3.Cursor) -> None:
+        if not cls.is_table_initialized(table_name, container_type, cur):
+            cls.do_create_table(table_name, container_type, cur)
+            cls.do_tidy_table_metadata(table_name, container_type, cur)
 
     @classmethod
-    def is_table_initialized(
-        self, table_name: str, container_type_name: str, schema_version: str, cur: sqlite3.Cursor
-    ) -> bool:
+    def is_table_initialized(cls, table_name: str, container_type_name: str, cur: sqlite3.Cursor) -> bool:
         try:
             cur.execute(
                 "SELECT schema_version FROM metadata WHERE table_name=? AND container_type=?",
@@ -145,7 +145,7 @@ class _SqliteCollectionBaseDatabaseDriver(metaclass=ABCMeta):
             if buf is None:
                 return False
             version = buf[0]
-            if version != schema_version:
+            if version != cls.schema_version:
                 return False
             cur.execute(f"SELECT 1 FROM {table_name} LIMIT 1")
             _ = list(cur)
@@ -155,19 +155,15 @@ class _SqliteCollectionBaseDatabaseDriver(metaclass=ABCMeta):
         return False
 
     @classmethod
-    def do_tidy_table_metadata(
-        cls, table_name: str, container_type_name: str, schema_version: str, cur: sqlite3.Cursor
-    ) -> None:
+    def do_tidy_table_metadata(cls, table_name: str, container_type_name: str, cur: sqlite3.Cursor) -> None:
         cur.execute(
             "INSERT INTO metadata (table_name, schema_version, container_type) VALUES (?, ?, ?)",
-            (table_name, schema_version, container_type_name),
+            (table_name, cls.schema_version, container_type_name),
         )
 
     @classmethod
     @abstractmethod
-    def do_create_table(
-        cls, table_name: str, container_type_name: str, schema_version: str, cur: sqlite3.Cursor
-    ) -> None:
+    def do_create_table(cls, table_name: str, container_type_name: str, cur: sqlite3.Cursor) -> None:
         ...
 
     @classmethod
@@ -184,6 +180,84 @@ class _SqliteCollectionBaseDatabaseDriver(metaclass=ABCMeta):
         cur.execute(f"ALTER TABLE {table_name} RENAME TO {new_table_name}")
 
 
+class MetadataItem(Hashable):
+    def __init__(self, table_name: str, schema_version: str, container_type: str):
+        self._table_name = table_name
+        self._schema_version = schema_version
+        self._container_type = container_type
+
+    @property
+    def table_name(self) -> str:
+        return self._table_name
+
+    @property
+    def schema_version(self) -> str:
+        return self._schema_version
+
+    @property
+    def container_type(self) -> str:
+        return self._container_type
+
+    def __eq__(self, __o: object) -> bool:
+        if isinstance(__o, MetadataItem):
+            return (
+                self.table_name == __o.table_name
+                and self.container_type == __o.container_type
+                and self.schema_version == __o.schema_version
+            )
+        return False
+
+    def __hash__(self) -> int:
+        return hash((self.table_name, self.schema_version, self.container_type))
+
+
+class MetadataDatabaseDriver:
+    @classmethod
+    def get_count(cls, cur: sqlite3.Cursor) -> int:
+        try:
+            cur.execute(f"SELECT COUNT(1) FROM metadata")
+            res = cur.fetchone()
+            return cast(int, res[0])
+        except sqlite3.OperationalError:
+            return 0
+
+    @classmethod
+    def is_metadata_in(cls, cur: sqlite3.Cursor, metadata: MetadataItem) -> bool:
+        try:
+            cur.execute(
+                "SELECT COUNT(1) FROM metadata WHERE table_name=? AND schema_version=? AND container_type=?",
+                (metadata.table_name, metadata.schema_version, metadata.container_type),
+            )
+            return cast(int, cur.fetchone()[0]) == 1
+        except sqlite3.OperationalError:
+            return False
+
+    @classmethod
+    def get_metadata(cls, cur: sqlite3.Cursor) -> Iterable[Tuple[str, str, str]]:
+        try:
+            cur.execute("SELECT table_name, schema_version, container_type FROM metadata")
+            yield from cur
+        except sqlite3.OperationalError:
+            yield from tuple()
+
+
+class MetadataReader(Collection[MetadataItem]):
+    def __init__(self, connection: Union[str, sqlite3.Connection]):
+        self._connection = tidy_connection(connection)
+
+    def __len__(self) -> int:
+        return MetadataDatabaseDriver.get_count(self._connection.cursor())
+
+    def __contains__(self, __x: object) -> bool:
+        if isinstance(__x, MetadataItem):
+            return MetadataDatabaseDriver.is_metadata_in(self._connection.cursor(), __x)
+        return False
+
+    def __iter__(self) -> Iterator[MetadataItem]:
+        for d in MetadataDatabaseDriver.get_metadata(self._connection.cursor()):
+            yield MetadataItem(table_name=d[0], schema_version=d[1], container_type=d[2])
+
+
 class SqliteCollectionBase(Generic[T], metaclass=ABCMeta):
     _driver_class = _SqliteCollectionBaseDatabaseDriver
 
@@ -202,7 +276,6 @@ class SqliteCollectionBase(Generic[T], metaclass=ABCMeta):
         serializer: Optional[Callable[[T], bytes]] = None,
         deserializer: Optional[Callable[[bytes], T]] = None,
         persist: bool = True,
-        rebuild_strategy: Optional[RebuildStrategy] = None,
     ):
         super(SqliteCollectionBase, self).__init__()
         self._serializer = self._default_serializer if serializer is None else serializer
@@ -214,42 +287,20 @@ class SqliteCollectionBase(Generic[T], metaclass=ABCMeta):
             if table_name is None
             else sanitize_table_name(table_name, self.container_type_name)
         )
-        self._initialize(rebuild_strategy=rebuild_strategy)
+        self._initialize()
 
     def __del__(self) -> None:
-        if not self.persist:
+        if hasattr(self, "persist") and not self.persist:
             cur = self.connection.cursor()
             self._driver_class.drop_table(self.table_name, self.container_type_name, cur)
             self.connection.commit()
 
-    def _initialize(self, rebuild_strategy: Optional[RebuildStrategy] = None) -> None:
+    def _initialize(self) -> None:
         cur = self.connection.cursor()
         self._driver_class.initialize_metadata_table(cur)
-        self._driver_class.initialize_table(self.table_name, self.container_type_name, self.schema_version, cur)
-        if self._should_rebuild(rebuild_strategy):
-            self._do_rebuild()
+        self._driver_class.initialize_table(self.table_name, self.container_type_name, cur)
         self.connection.commit()
 
-    def _should_rebuild(self, rebuild_strategy: Optional[RebuildStrategy] = None) -> bool:
-        if rebuild_strategy is None or rebuild_strategy == RebuildStrategy.SKIP:
-            return False
-        warnings.warn(
-            "rebuild_strategy argument and rebuilding DB feature are deprecated and will be removed in version 1.0.0",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        if rebuild_strategy == RebuildStrategy.ALWAYS:
-            return True
-        return self._rebuild_check_with_first_element()
-
-    @abstractmethod
-    def _rebuild_check_with_first_element(self) -> bool:
-        ...
-
-    @abstractmethod
-    def _do_rebuild(self) -> None:
-        ...
-
     @property
     def persist(self) -> bool:
         return self._persist
@@ -293,8 +344,3 @@ class SqliteCollectionBase(Generic[T], metaclass=ABCMeta):
     @property
     def container_type_name(self) -> str:
         return self.__class__.__name__
-
-    @property
-    @abstractmethod
-    def schema_version(self) -> str:
-        ...
