@@ -37,11 +37,13 @@ if sys.version_info >= (3, 9):
     from collections.abc import KeysView as KeysViewType
     from collections.abc import ValuesView as ValuesViewType
 else:
+    from typing import ItemsView as ItemsViewType
     from typing import KeysView as KeysViewType
     from typing import ValuesView as ValuesViewType
-    from typing import ItemsView as ItemsViewType
 
-from . import RebuildStrategy
+if sys.version_info > (3, 10):
+    from types import MappingProxyType
+
 from .base import (
     _T,
     KT,
@@ -58,10 +60,18 @@ _VT_co = TypeVar("_VT_co", covariant=True)
 
 
 class _DictDatabaseDriver(_SqliteCollectionBaseDatabaseDriver):
+    if sys.version_info >= (3, 9):
+
+        @classmethod
+        @property
+        def schema_version(cls) -> str:
+            return "0"
+
+    else:
+        schema_version = "0"
+
     @classmethod
-    def do_create_table(
-        cls, table_name: str, container_type_nam: str, schema_version: str, cur: sqlite3.Cursor
-    ) -> None:
+    def do_create_table(cls, table_name: str, container_type_nam: str, cur: sqlite3.Cursor) -> None:
         cur.execute(
             f"CREATE TABLE {table_name} ("
             "serialized_key BLOB NOT NULL UNIQUE, "
@@ -191,59 +201,24 @@ class _Dict(SqliteCollectionBase[KT], MutableMapping[KT, VT], Generic[KT, VT]):
         key_deserializer: Optional[Callable[[bytes], KT]] = None,
         value_serializer: Optional[Callable[[VT], bytes]] = None,
         value_deserializer: Optional[Callable[[bytes], VT]] = None,
-        serializer: Optional[Callable[[VT], bytes]] = None,
-        deserializer: Optional[Callable[[bytes], VT]] = None,
         persist: bool = True,
-        rebuild_strategy: Optional[RebuildStrategy] = None,
-        data: Optional[Union[Iterable[Tuple[KT, VT]], Mapping[KT, VT]]] = None,
     ) -> None:
-        if serializer is not None:
-            warnings.warn(
-                "serializer argument is deprecated. use key_serializer or value_serializer instead",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-        self._value_serializer = (
-            value_serializer
-            if value_serializer is not None
-            else serializer
-            if serializer is not None
-            else cast(Callable[[VT], bytes], self._default_serializer if key_serializer is None else key_serializer)
-        )
-        if deserializer is not None:
-            warnings.warn(
-                "deserializer argument is deprecated. use key_deserializer or value_deserializer instead",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-        self._value_deserializer = (
-            value_deserializer
-            if value_deserializer is not None
-            else deserializer
-            if deserializer is not None
-            else cast(
-                Callable[[bytes], VT], self._default_deserializer if key_deserializer is None else key_deserializer
-            )
-        )
         super(_Dict, self).__init__(
             connection=connection,
             table_name=table_name,
             serializer=key_serializer,
             deserializer=key_deserializer,
             persist=persist,
-            rebuild_strategy=rebuild_strategy,
         )
-        if data is not None or __data is not None:
+        self._value_serializer = (
+            value_serializer if value_serializer is not None else cast(Callable[[VT], bytes], self.key_serializer)
+        )
+        self._value_deserializer = (
+            value_deserializer if value_deserializer is not None else cast(Callable[[bytes], VT], self.key_deserializer)
+        )
+        if __data is not None:
             self.clear()
-            if data is not None:
-                warnings.warn(
-                    "data keyword argument is deprecated and will be removed in version 1.0.0",
-                    DeprecationWarning,
-                    stacklevel=2,
-                )
-                self.update(data)
-            if __data is not None:
-                self.update(__data)
+            self.update(__data)
 
     @property
     def key_serializer(self) -> Callable[[KT], bytes]:
@@ -261,47 +236,6 @@ class _Dict(SqliteCollectionBase[KT], MutableMapping[KT, VT], Generic[KT, VT]):
     def value_deserializer(self) -> Callable[[bytes], VT]:
         return self._value_deserializer
 
-    @property
-    def schema_version(self) -> str:
-        return "0"
-
-    def _rebuild_check_with_first_element(self) -> bool:
-        cur = self.connection.cursor()
-        cur.execute(f"SELECT serialized_key FROM {self.table_name} ORDER BY item_order LIMIT 1")
-        res = cur.fetchone()
-        if res is None:
-            return False
-        serialized_key = cast(bytes, res[0])
-        key = self.deserialize_key(serialized_key)
-        return serialized_key != self.serialize_key(key)
-
-    def _do_rebuild(self) -> None:
-        cur = self.connection.cursor()
-        last_order = -1
-        while last_order is not None:
-            cur.execute(
-                f"SELECT item_order FROM {self.table_name} WHERE item_order > ? ORDER BY item_order LIMIT 1",
-                (last_order,),
-            )
-            res = cur.fetchone()
-            if res is None:
-                break
-            i = res[0]
-            cur.execute(
-                f"SELECT serialized_key, serialized_value FROM {self.table_name} WHERE item_order=?",
-                (i,),
-            )
-            serialized_key, serialized_value = cur.fetchone()
-            cur.execute(
-                f"UPDATE {self.table_name} SET serialized_key=?, serialized_value=? WHERE item_order=?",
-                (
-                    self.serialize_key(self.deserialize_key(serialized_key)),
-                    self.serialize_value(self.deserialize_value(serialized_value)),
-                    i,
-                ),
-            )
-            last_order = i
-
     def serialize_key(self, key: KT) -> bytes:
         if not is_hashable(key):
             raise TypeError(f"unhashable type: '{type(key).__name__}'")
@@ -362,7 +296,6 @@ class _Dict(SqliteCollectionBase[KT], MutableMapping[KT, VT], Generic[KT, VT]):
             key_deserializer=self.key_deserializer,
             value_serializer=self.value_serializer,
             value_deserializer=self.value_deserializer,
-            rebuild_strategy=RebuildStrategy.SKIP,
             persist=False,
         )
 
@@ -521,10 +454,16 @@ else:
 
 class MappingView(Sized):
     def __init__(self, mapping: Dict[Any, Any]):
-        self._parent = mapping
+        self._mapping = mapping
 
     def __len__(self) -> int:
-        return len(self._parent)
+        return len(self._mapping)
+
+    if sys.version_info > (3, 10):
+
+        @property
+        def mapping(self) -> MappingProxyType:
+            return MappingProxyType(self._mapping)
 
 
 class KeysView(MappingView, KeysViewType[_KT_co], Generic[_KT_co]):
@@ -533,39 +472,39 @@ class KeysView(MappingView, KeysViewType[_KT_co], Generic[_KT_co]):
 
     def __and__(self, o: Iterable[Any]) -> sc_Set[_KT_co]:  # type: ignore[override]
         return sc_Set[_KT_co](
-            (d for d in o if d in self._parent),
-            connection=self._parent.connection,
-            serializer=self._parent.key_serializer,
-            deserializer=self._parent.key_deserializer,
+            (d for d in o if d in self._mapping),
+            connection=self._mapping.connection,
+            serializer=self._mapping.key_serializer,
+            deserializer=self._mapping.key_deserializer,
             persist=False,
         )
 
     def __rand__(self, o: Iterable[_T]) -> sc_Set[_T]:  # type: ignore[override]
         return sc_Set[_T](
-            (d for d in o if d in self._parent),
-            connection=self._parent.connection,
-            serializer=self._parent.key_serializer,
-            deserializer=self._parent.key_deserializer,
+            (d for d in o if d in self._mapping),
+            connection=self._mapping.connection,
+            serializer=self._mapping.key_serializer,
+            deserializer=self._mapping.key_deserializer,
             persist=False,
         )
 
     def __contains__(self, o: object) -> bool:
-        return o in self._parent
+        return o in self._mapping
 
     def __iter__(self) -> Iterator[_KT_co]:
-        return iter(self._parent)
+        return iter(self._mapping)
 
     if sys.version_info >= (3, 8):
 
         def __reversed__(self) -> Iterator[_KT_co]:
-            return reversed(self._parent)
+            return reversed(self._mapping)
 
     def __or__(self, o: Iterable[_T]) -> sc_Set[Union[_KT_co, _T]]:  # type: ignore[override]
         return sc_Set[Union[_KT_co, _T]](
-            itertools.chain(self._parent, o),
-            connection=self._parent.connection,
-            serializer=self._parent.key_serializer,
-            deserializer=self._parent.key_deserializer,
+            itertools.chain(self._mapping, o),
+            connection=self._mapping.connection,
+            serializer=self._mapping.key_serializer,
+            deserializer=self._mapping.key_deserializer,
             persist=False,
         )
 
@@ -574,28 +513,28 @@ class KeysView(MappingView, KeysViewType[_KT_co], Generic[_KT_co]):
 
     def __sub__(self, o: Iterable[Any]) -> sc_Set[_KT_co]:  # type: ignore[override]
         return sc_Set[KT](
-            self._parent,
-            connection=self._parent.connection,
-            serializer=self._parent.key_serializer,
-            deserializer=self._parent.key_deserializer,
+            self._mapping,
+            connection=self._mapping.connection,
+            serializer=self._mapping.key_serializer,
+            deserializer=self._mapping.key_deserializer,
             persist=False,
         ).difference(o)
 
     def __rsub__(self, o: Iterable[_T]) -> sc_Set[_T]:  # type: ignore[override]
         return sc_Set[_T](
             o,
-            connection=self._parent.connection,
-            serializer=self._parent.key_serializer,
-            deserializer=self._parent.key_deserializer,
+            connection=self._mapping.connection,
+            serializer=self._mapping.key_serializer,
+            deserializer=self._mapping.key_deserializer,
             persist=False,
-        ).difference(self._parent)
+        ).difference(self._mapping)
 
     def __xor__(self, o: Iterable[_T]) -> sc_Set[Union[_KT_co, _T]]:  # type: ignore[override]
         return sc_Set[Union[KT, _T]](
-            self._parent,
-            connection=self._parent.connection,
-            serializer=self._parent.key_serializer,
-            deserializer=self._parent.key_deserializer,
+            self._mapping,
+            connection=self._mapping.connection,
+            serializer=self._mapping.key_serializer,
+            deserializer=self._mapping.key_deserializer,
             persist=False,
         ).symmetric_difference(o)
 
@@ -614,16 +553,16 @@ class ValuesView(MappingView, ValuesViewType[_VT_co], Generic[_VT_co]):
         return False
 
     def __iter__(self) -> Iterator[_VT_co]:
-        cur = self._parent.connection.cursor()
-        for sv in self._parent._driver_class.get_serialized_values(self._parent.table_name, cur):
-            yield self._parent.deserialize_value(sv)
+        cur = self._mapping.connection.cursor()
+        for sv in self._mapping._driver_class.get_serialized_values(self._mapping.table_name, cur):
+            yield self._mapping.deserialize_value(sv)
 
     if sys.version_info >= (3, 8):
 
         def __reversed__(self) -> Iterator[_VT_co]:
-            cur = self._parent.connection.cursor()
-            for sv in self._parent._driver_class.get_reversed_serialized_values(self._parent.table_name, cur):
-                yield self._parent.deserialize_value(sv)
+            cur = self._mapping.connection.cursor()
+            for sv in self._mapping._driver_class.get_reversed_serialized_values(self._mapping.table_name, cur):
+                yield self._mapping.deserialize_value(sv)
 
 
 class ItemsView(MappingView, ItemsViewType[_KT_co, _VT_co]):
@@ -631,12 +570,12 @@ class ItemsView(MappingView, ItemsViewType[_KT_co, _VT_co]):
         if not is_hashable(o[1]):
             raise TypeError(f"unhashable type: '{type(o[1]).__name__}'")
         return SqliteCollectionBase[Tuple[bytes, bytes]]._default_serializer(
-            (self._parent.serialize_key(o[0]), self._parent.serialize_value(o[1]))
+            (self._mapping.serialize_key(o[0]), self._mapping.serialize_value(o[1]))
         )
 
     def _item_deserializer(self, o: bytes) -> Tuple[_KT_co, _VT_co]:
         sk, sv = SqliteCollectionBase[Tuple[bytes, bytes]]._default_deserializer(o)
-        return (self._parent.deserialize_key(sk), self._parent.deserialize_value(sv))
+        return (self._mapping.deserialize_key(sk), self._mapping.deserialize_value(sv))
 
     def __init__(self, mapping: Dict[_KT_co, _VT_co]) -> None:
         super(ItemsView, self).__init__(mapping)
@@ -644,14 +583,14 @@ class ItemsView(MappingView, ItemsViewType[_KT_co, _VT_co]):
     def __and__(self, o: Iterable[Any]) -> sc_Set[Tuple[_KT_co, _VT_co]]:  # type: ignore[override]
         tmp = sc_Set[Tuple[_KT_co, _VT_co]](
             iter(self),
-            connection=self._parent.connection,
+            connection=self._mapping.connection,
             serializer=self._item_serializer,
             deserializer=self._item_deserializer,
             persist=False,
         )
         return sc_Set[Tuple[_KT_co, _VT_co]](
             (cast(Tuple[_KT_co, _VT_co], d) for d in o if d in tmp),
-            connection=self._parent.connection,
+            connection=self._mapping.connection,
             serializer=self._item_serializer,
             deserializer=self._item_deserializer,
             persist=False,
@@ -661,14 +600,14 @@ class ItemsView(MappingView, ItemsViewType[_KT_co, _VT_co]):
         return cast(sc_Set[_T], self & o)
 
     def __contains__(self, o: object) -> bool:
-        if not isinstance(o, tuple) or len(o) != 2 or o[0] not in self._parent:
+        if not isinstance(o, tuple) or len(o) != 2 or o[0] not in self._mapping:
             return False
-        return bool(self._parent[o[0]] == o[1])
+        return bool(self._mapping[o[0]] == o[1])
 
     def __iter__(self) -> Iterator[Tuple[_KT_co, _VT_co]]:
-        cur = self._parent.connection.cursor()
-        for sk, sv in self._parent._driver_class.get_serialized_items(self._parent.table_name, cur):
-            yield self._parent.deserialize_key(sk), self._parent.deserialize_value(sv)
+        cur = self._mapping.connection.cursor()
+        for sk, sv in self._mapping._driver_class.get_serialized_items(self._mapping.table_name, cur):
+            yield self._mapping.deserialize_key(sk), self._mapping.deserialize_value(sv)
 
     if sys.version_info >= (3, 8):
 
@@ -678,7 +617,7 @@ class ItemsView(MappingView, ItemsViewType[_KT_co, _VT_co]):
     def __or__(self, o: Iterable[_T]) -> sc_Set[Union[Tuple[_KT_co, _VT_co], _T]]:  # type: ignore[override]
         return sc_Set[Union[Tuple[_KT_co, _VT_co], _T]](
             itertools.chain(self, o),
-            connection=self._parent.connection,
+            connection=self._mapping.connection,
             serializer=cast(Callable[[Union[Tuple[_KT_co, _VT_co], _T]], bytes], self._item_serializer),
             deserializer=cast(Callable[[bytes], Union[Tuple[_KT_co, _VT_co], _T]], self._item_deserializer),
             persist=False,
@@ -690,7 +629,7 @@ class ItemsView(MappingView, ItemsViewType[_KT_co, _VT_co]):
     def __sub__(self, o: Iterable[Any]) -> sc_Set[Tuple[_KT_co, _VT_co]]:  # type: ignore[override]
         tmp = sc_Set[Tuple[_KT_co, _VT_co]](
             iter(self),
-            connection=self._parent.connection,
+            connection=self._mapping.connection,
             serializer=self._item_serializer,
             deserializer=self._item_deserializer,
             persist=False,
@@ -701,21 +640,21 @@ class ItemsView(MappingView, ItemsViewType[_KT_co, _VT_co]):
     def __rsub__(self, o: Iterable[_T]) -> sc_Set[_T]:  # type: ignore[override]
         tmp = sc_Set[Tuple[_KT_co, _VT_co]](
             iter(self),
-            connection=self._parent.connection,
+            connection=self._mapping.connection,
             serializer=self._item_serializer,
             deserializer=self._item_deserializer,
             persist=False,
         )
         return sc_Set[_T](
             (d for d in o if d not in tmp),
-            connection=self._parent.connection,
+            connection=self._mapping.connection,
             persist=False,
         )
 
     def __xor__(self, o: Iterable[_T]) -> sc_Set[Union[Tuple[_KT_co, _VT_co], _T]]:  # type: ignore[override]
         tmp = sc_Set[Union[Tuple[_KT_co, _VT_co], _T]](
             iter(self),
-            connection=self._parent.connection,
+            connection=self._mapping.connection,
             serializer=cast(Callable[[Union[Tuple[_KT_co, _VT_co], _T]], bytes], self._item_serializer),
             deserializer=cast(Callable[[bytes], Union[Tuple[_KT_co, _VT_co], _T]], self._item_deserializer),
             persist=False,
