@@ -9,7 +9,6 @@ if sys.version_info >= (3, 9):
 else:
     from typing import Iterable, Iterator, MutableSet, Callable
 
-from . import RebuildStrategy
 from .base import (
     _S,
     _T,
@@ -22,10 +21,18 @@ from .base import (
 
 
 class _SetDatabaseDriver(_SqliteCollectionBaseDatabaseDriver):
+    if sys.version_info >= (3, 9):
+
+        @classmethod
+        @property
+        def schema_version(cls) -> str:
+            return "0"
+
+    else:
+        schema_version = "0"
+
     @classmethod
-    def do_create_table(
-        cls, table_name: str, container_type_nam: str, schema_version: str, cur: sqlite3.Cursor
-    ) -> None:
+    def do_create_table(cls, table_name: str, container_type_nam: str, cur: sqlite3.Cursor) -> None:
         cur.execute(f"CREATE TABLE {table_name} (serialized_value BLOB PRIMARY KEY)")
 
     @classmethod
@@ -141,8 +148,6 @@ class Set(SqliteCollectionBase[T], MutableSet[T]):
         serializer: Optional[Callable[[T], bytes]] = None,
         deserializer: Optional[Callable[[bytes], T]] = None,
         persist: bool = True,
-        rebuild_strategy: Optional[RebuildStrategy] = None,
-        data: Optional[Iterable[T]] = None,
     ) -> None:
         super(Set, self).__init__(
             connection=connection,
@@ -150,19 +155,10 @@ class Set(SqliteCollectionBase[T], MutableSet[T]):
             serializer=serializer,
             deserializer=deserializer,
             persist=persist,
-            rebuild_strategy=rebuild_strategy,
         )
-        if data is not None or __data is not None:
+        if __data is not None:
             self.clear()
-            if data is not None:
-                warnings.warn(
-                    "data keyword argument is deprecated and will be removed in version 1.0.0",
-                    DeprecationWarning,
-                    stacklevel=2,
-                )
-                self.update(data)
-            if __data is not None:
-                self.update(__data)
+            self.update(__data)
 
     def __contains__(self, value: object) -> bool:
         cur = self.connection.cursor()
@@ -178,33 +174,6 @@ class Set(SqliteCollectionBase[T], MutableSet[T]):
         cur = self.connection.cursor()
         return self._driver_class.get_count(self.table_name, cur)
 
-    def _do_rebuild(self) -> None:
-        cur = self.connection.cursor()
-        backup_table_name = f'bk_{self.container_type_name}_{str(uuid4()).replace("-", "")}'
-        cur.execute(f"CREATE TABLE {backup_table_name} AS SELECT * FROM {self.table_name}")
-        cur.execute(f"DELETE FROM {self.table_name}")
-        iter_old_records = self.connection.cursor()
-        iter_old_records.execute(f"SELECT serialized_value FROM {backup_table_name}")
-        delete_old_records = self.connection.cursor()
-        insert_new_records = self.connection.cursor()
-        for d in iter_old_records:
-            insert_new_records.execute(
-                f"INSERT INTO {self.table_name} (serialized_value) VALUES (?)",
-                (self.serialize(self.deserialize(d[0])),),
-            )
-            delete_old_records.execute(f"DELETE FROM {backup_table_name} WHERE serialized_value = ?", d)
-        cur.execute(f"DROP TABLE {backup_table_name}")
-
-    def _rebuild_check_with_first_element(self) -> bool:
-        cur = self.connection.cursor()
-        cur.execute(f"SELECT serialized_value FROM {self.table_name} LIMIT 1")
-        res = cur.fetchone()
-        if res is None:
-            return False
-        serialized_value = cast(bytes, res[0])
-        value = self.deserialize(serialized_value)
-        return serialized_value != self.serialize(value)
-
     def serialize(self, value: T) -> bytes:
         if not is_hashable(value):
             raise TypeError(f"unhashable type: '{type(value).__name__}'")
@@ -243,10 +212,6 @@ class Set(SqliteCollectionBase[T], MutableSet[T]):
         self.connection.commit()
         return self.deserialize(serialized_value)
 
-    @property
-    def schema_version(self) -> str:
-        return "0"
-
     def issubset(self, other: Iterable[T]) -> bool:
         return len(self) == len(self.intersection(other))
 
@@ -335,7 +300,6 @@ class Set(SqliteCollectionBase[T], MutableSet[T]):
             connection=self.connection,
             serializer=self.serializer,
             deserializer=self.deserializer,
-            rebuild_strategy=RebuildStrategy.SKIP,
             persist=False,
         )
 
